==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/HttpConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class HttpConfiguration(baseUrl: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.HttpConfiguration = {
    import HttpConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.HttpConfiguration
      .builder()
      .baseUrl(__string.unwrap(baseUrl): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.HttpConfiguration.ReadOnly =
    zio.aws.mediatailor.model.HttpConfiguration.wrap(buildAwsValue())
}
object HttpConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.HttpConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.HttpConfiguration =
      zio.aws.mediatailor.model.HttpConfiguration(baseUrl)
    def baseUrl: __string
    def getBaseUrl: ZIO[Any, Nothing, __string] = ZIO.succeed(baseUrl)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.HttpConfiguration
  ) extends zio.aws.mediatailor.model.HttpConfiguration.ReadOnly {
    override val baseUrl: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.baseUrl())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.HttpConfiguration
  ): zio.aws.mediatailor.model.HttpConfiguration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.19.33.1-sources.jar: zio/aws/mediatailor/model/HttpConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class HttpConfiguration(baseUrl: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.HttpConfiguration = {
    import HttpConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.HttpConfiguration
      .builder()
      .baseUrl(baseUrl: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.HttpConfiguration.ReadOnly =
    zio.aws.mediatailor.model.HttpConfiguration.wrap(buildAwsValue())
}
object HttpConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.HttpConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.HttpConfiguration =
      zio.aws.mediatailor.model.HttpConfiguration(baseUrl)
    def baseUrl: __string
    def getBaseUrl: ZIO[Any, Nothing, __string] = ZIO.succeed(baseUrl)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.HttpConfiguration
  ) extends zio.aws.mediatailor.model.HttpConfiguration.ReadOnly {
    override val baseUrl: __string = impl.baseUrl(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.HttpConfiguration
  ): zio.aws.mediatailor.model.HttpConfiguration.ReadOnly = new Wrapper(impl)
}
